Crate codama_attributes

Crate codama_attributes 

Macros

assert_type
assert_type_err
assert_value
assert_value_err

Structs

AccountDirective
ArgumentDirective
Attributes
CodamaAttribute
CodamaProgramMacro
The parsed arguments of a codama_program! function-like macro invocation.
DefaultValueDirective
DeriveAttribute
DiscriminatorDirective
DisplayDirective
EncodingDirective
EnumDiscriminatorDirective
ErrorDirective
ExportDirective
FieldDirective
FixedSizeDirective
NameDirective
OptionalAccountStrategyDirective
PdaDirective
ProgramDirective
RemainingAccountsDirective
ReprAttribute
ResolvableDirective
A directive that needs to be resolved by an external extension. Resolvable directives are detected by the prefix::name(...) syntax where the path contains exactly two segments separated by ::.
SeedDirective
SizePrefixDirective
SkipDirective
TypeDirective
UnsupportedAttribute

Enums

Attribute
AttributeContext
CodamaDirective
Resolvable
A value that is either resolved to a concrete node T or deferred to an extension for resolution.
SeedDirectiveType
TypeDirectiveNode

Traits

TryFromFilter