Resolvable

Enum Resolvable 

pub enum Resolvable<T> {
    Resolved(T),
    Unresolved(Box<ResolvableDirective>),
}
A value that is either resolved to a concrete node T or deferred to an extension for resolution.

Variants



Resolved(T)

The value has been resolved to a concrete node.



Unresolved(Box<ResolvableDirective>)

The value needs to be resolved by an extension.

Implementations

Source

impl<T: FromMeta> Resolvable<T>

pub fn from_meta(meta: &Meta) -> Result<Self>

Parse a Meta into a Resolvable<T>. If the path has exactly two segments (i.e. prefix::name), returns Unresolved(ResolvableDirective). Otherwise, delegates to T::from_meta.

Source

impl<T> Resolvable<T>

pub fn resolved(&self) -> Option<&T>

Returns a reference to the resolved value, or None if unresolved.

pub fn try_resolved(&self) -> Result<&T, CodamaError>

Returns the resolved value, or an error if unresolved.

pub fn try_into_resolved(self) -> Result<T, CodamaError>

Consumes self and returns the resolved value, or an error if unresolved.

pub fn is_unresolved(&self) -> bool

Returns true if this is an unresolved directive.

pub fn is_resolved(&self) -> bool

Returns true if this is a resolved value.

pub fn map<U>(self, f: impl FnOnce(T) -> U) -> Resolvable<U>

Maps the resolved value using the given function.