pub enum SeedDirectiveType {
Linked(String),
Variable {
name: String,
type: Resolvable<TypeNode>,
},
Constant {
type: Resolvable<TypeNode>,
value: Resolvable<ValueNode>,
},
}Variants
Linked(String)
A seed that references a field by name. The type is inferred from the field.
Variable
A variable seed with a name and type (which may be a plugin directive).
Constant
A constant seed with a type and value (which may be plugin directives).