ReprAttribute

Struct ReprAttribute 

pub struct ReprAttribute<'a> {
    pub ast: &'a Attribute,
    pub metas: Vec<Meta>,
}

Fields

ast: &'a Attributemetas: Vec<Meta>

Implementations

Source

impl<'a> ReprAttribute<'a>

pub fn parse(ast: &'a Attribute) -> Result<Self>

pub fn parse_from(ast: &'a Attribute, effective: &Attribute) -> Result<Self>

Parse a repr attribute using the effective attribute for content extraction. ast is stored as the original attribute reference (for error spans). effective is used to parse the actual repr list.

pub fn get_number_type_node(&self) -> Option<NumberTypeNode>