pub struct ResolvableDirective {
pub namespace: String,
pub name: String,
pub meta: Meta,
}Expand description
A directive that needs to be resolved by an external extension.
Resolvable directives are detected by the prefix::name(...) syntax where
the path contains exactly two segments separated by ::.
Fields
namespace: StringThe namespace prefix, e.g. "wellknown" in wellknown::ata(...).
name: StringThe directive name, e.g. "ata" in wellknown::ata(...).
meta: MetaThe full Meta content for the extension to parse during resolution.