pub struct DeriveAttribute<'a> {
pub ast: &'a Attribute,
pub derives: Vec<Path>,
}Fields
ast: &'a Attributederives: Vec<Path>Implementations
Sourceimpl<'a> DeriveAttribute<'a>
impl<'a> DeriveAttribute<'a>
pub fn parse(ast: &'a Attribute) -> Result<Self>
Sourcepub fn parse_from(ast: &'a Attribute, effective: &Attribute) -> Result<Self>
pub fn parse_from(ast: &'a Attribute, effective: &Attribute) -> Result<Self>
Parse a derive attribute using the effective attribute for content extraction.
ast is stored as the original attribute reference (for error spans).
effective is used to parse the actual derive list.